pub enum QueryMsg {
OwnerOf {
token_id: String,
include_expired: Option<bool>,
},
ApprovedForAll {
owner: String,
include_expired: Option<bool>,
start_after: Option<String>,
limit: Option<u32>,
},
NumTokens {},
ContractInfo {},
NftInfo {
token_id: String,
},
AllNftInfo {
token_id: String,
include_expired: Option<bool>,
},
Tokens {
owner: String,
start_after: Option<String>,
limit: Option<u32>,
},
AllTokens {
start_after: Option<String>,
limit: Option<u32>,
},
Minter {},
}Variants
OwnerOf
Return the owner of the given token, error if token does not exist Return type: OwnerOfResponse
Fields
ApprovedForAll
List all operators that can access all of the owner’s tokens
Return type: ApprovedForAllResponse
Fields
NumTokens
Total number of tokens issued
ContractInfo
With MetaData Extension.
Returns top-level metadata about the contract: ContractInfoResponse
NftInfo
With MetaData Extension.
Returns metadata about one particular token, based on ERC721 Metadata JSON Schema
but directly from the contract: NftInfoResponse
AllNftInfo
With MetaData Extension.
Returns the result of both NftInfo and OwnerOf as one query as an optimization
for clients: AllNftInfo
Fields
Tokens
With Enumerable extension. Returns all tokens owned by the given address, [] if unset. Return type: TokensResponse.
AllTokens
With Enumerable extension. Requires pagination. Lists all token_ids controlled by the contract. Return type: TokensResponse.
Minter